Changes
=======

v0.1.6
------

* Fix return error when package/module is not installed

v0.1.5
------

* Fix calling non callable objects in is_what()

v0.1.3
------

* Remove break if an import is not found, but log the error

v0.1.2
------

* Fix entry point function call arguments
* Enhance arguments options and order


v0.1.1
------

* Fix setup to install as Python module
* Fix ancestors method to correct assign of child classes


v0.1
----

* First working version
